@@ -1,14 +1,14 @@
-use wolf_engine::context::Subcontext;
-use wolf_engine::*;
-
 use log::*;
+use wolf_engine::*;
 
 pub fn main() {
     #[cfg(feature = "logging")]
-    wolf_engine::initialize_logging(LevelFilter::Info);
+    wolf_engine::logging::initialize_logging(LevelFilter::Info);
 
     let mut context = Context::default();
-    context.add_subcontext(CustomContext::new("Hello, World!"));
+    context
+        .add(CustomContext::new("Hello, World!"))
+        .expect("failed to add subcontext");
 
     EngineBuilder::new().build(context).run(Box::from(MyState));
 }
@@ -33,7 +33,7 @@ pub struct MyState;
 
 impl State for MyState {
     fn update(&mut self, context: &mut Context) -> OptionalTransition {
-        let custom_context = context.get_subcontext_mut::<CustomContext>().unwrap();
+        let custom_context = context.get_mut::<CustomContext>().unwrap();
         if custom_context.count == 10 {
             Some(Transition::Quit)
         } else {
@@ -43,7 +43,7 @@ impl State for MyState {
     }
 
     fn render(&mut self, context: &mut Context) -> RenderResult {
-        let custom_context = context.get_subcontext::<CustomContext>().unwrap();
+        let custom_context = context.get::<CustomContext>().unwrap();
         info!("{}: {}", custom_context.message, custom_context.count);
     }
 }
